@@ -5,7 +5,7 @@
 
    Copyright (C) 1997-2005 Luke Howard
    Copyright (C) 2007 West Consulting
-   Copyright (C) 2007-2014 Arthur de Jong
+   Copyright (C) 2007-2015 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -143,7 +143,7 @@ static char *get_token(char **line, char *buf, size_t buflen)
 static char *get_strdup(const char *filename, int lnr,
                         const char *keyword, char **line)
 {
-  char token[64];
+  char token[MAX_LINE_LENGTH];
   check_argumentcount(filename, lnr, keyword,
                       get_token(line, token, sizeof(token)) != NULL);
   return xstrdup(token);
@@ -165,7 +165,7 @@ static void get_eol(const char *filename, int lnr,
 {
   if ((line != NULL) && (*line != NULL) && (**line != '\0'))
   {
-    log_log(LOG_ERR, "%s:%d: %s: too may arguments", filename, lnr, keyword);
+    log_log(LOG_ERR, "%s:%d: %s: too many arguments", filename, lnr, keyword);
     exit(EXIT_FAILURE);
   }
 }
@@ -1191,6 +1191,8 @@ static void cfg_defaults(struct ldap_config *cfg)
   cfg->nss_initgroups_ignoreusers = NULL;
   cfg->nss_min_uid = 0;
   cfg->nss_nested_groups = 0;
+  cfg->nss_getgrent_skipmembers = 0;
+  cfg->nss_disable_enumeration = 0;
   cfg->validnames_str = NULL;
   handle_validnames(__FILE__, __LINE__, "",
                     "/^[a-z0-9._@$()]([a-z0-9._@$() \\~-]*[a-z0-9._@$()~-])?$/i",
@@ -1517,6 +1519,16 @@ static void cfg_read(const char *filename, struct ldap_config *cfg)
       cfg->nss_nested_groups = get_boolean(filename, lnr, keyword, &line);
       get_eol(filename, lnr, keyword, &line);
     }
+    else if (strcasecmp(keyword, "nss_getgrent_skipmembers") == 0)
+    {
+      cfg->nss_getgrent_skipmembers = get_boolean(filename, lnr, keyword, &line);
+      get_eol(filename, lnr, keyword, &line);
+    }
+    else if (strcasecmp(keyword, "nss_disable_enumeration") == 0)
+    {
+      cfg->nss_getgrent_skipmembers = get_boolean(filename, lnr, keyword, &line);
+      get_eol(filename, lnr, keyword, &line);
+    }
     else if (strcasecmp(keyword, "validnames") == 0)
     {
       handle_validnames(filename, lnr, keyword, line, cfg);
@@ -1785,6 +1797,8 @@ static void cfg_dump(void)
   }
   log_log(LOG_DEBUG, "CFG: nss_min_uid %lu", (unsigned long int)nslcd_cfg->nss_min_uid);
   log_log(LOG_DEBUG, "CFG: nss_nested_groups %s", print_boolean(nslcd_cfg->nss_nested_groups));
+  log_log(LOG_DEBUG, "CFG: nss_getgrent_skipmembers %s", print_boolean(nslcd_cfg->nss_getgrent_skipmembers));
+  log_log(LOG_DEBUG, "CFG: nss_disable_enumeration %s", print_boolean(nslcd_cfg->nss_disable_enumeration));
   log_log(LOG_DEBUG, "CFG: validnames %s", nslcd_cfg->validnames_str);
   log_log(LOG_DEBUG, "CFG: ignorecase %s", print_boolean(nslcd_cfg->ignorecase));
   for (i = 0; i < NSS_LDAP_CONFIG_MAX_AUTHZ_SEARCHES; i++)
