@@ -534,10 +534,10 @@ static int do_ppolicy_bind(MYLDAP_SESSION *session, LDAP *ld, const char *uri)
   requestctrls[1] = NULL;
   /* build password berval */
   cred.bv_val = (char *)session->bindpw;
-  cred.bv_len = (session->bindpw == NULL) ? 0 : strlen(session->bindpw);
+  cred.bv_len = strlen(session->bindpw);
   /* do a SASL simple bind with the binddn and bindpw */
   log_log(LOG_DEBUG, "ldap_sasl_bind(\"%s\",%s) (uri=\"%s\")", session->binddn,
-          ((session->bindpw != NULL) && (session->bindpw[0] != '\0')) ? "\"***\"" : "\"\"", uri);
+          (session->bindpw[0] != '\0') ? "\"***\"" : "\"\"", uri);
   rc = ldap_sasl_bind(ld, session->binddn, LDAP_SASL_SIMPLE, &cred, requestctrls, NULL, &msgid);
   if (rc != LDAP_SUCCESS)
     return rc;
@@ -622,7 +622,7 @@ static int do_bind(MYLDAP_SESSION *session, LDAP *ld, const char *uri)
   }
 #endif /* LDAP_OPT_X_TLS */
   /* check if the binddn and bindpw are overwritten in the session */
-  if ((session->binddn != NULL) && (session->binddn[0] != '\0'))
+  if (session->binddn[0] != '\0')
   {
 #if defined(HAVE_LDAP_SASL_BIND) && defined(LDAP_SASL_SIMPLE)
     return do_ppolicy_bind(session, ld, uri);
@@ -630,7 +630,7 @@ static int do_bind(MYLDAP_SESSION *session, LDAP *ld, const char *uri)
     /* do a simple bind */
     log_log(LOG_DEBUG, "ldap_simple_bind_s(\"%s\",%s) (uri=\"%s\")",
             session->binddn,
-            ((session->bindpw != NULL) && (session->bindpw[0] != '\0')) ? "\"***\"" : "\"\"",
+            (session->bindpw[0] != '\0') ? "\"***\"" : "\"\"",
             uri);
     return ldap_simple_bind_s(ld, session->binddn, session->bindpw);
 #endif
@@ -952,6 +952,10 @@ void myldap_session_check(MYLDAP_SESSION *session)
 {
   int i;
   time_t current_time;
+  int sd;
+  int rc;
+  struct sockaddr sa;
+  socklen_t salen = sizeof(sa);
   /* check parameters */
   if (session == NULL)
   {
@@ -959,19 +963,41 @@ void myldap_session_check(MYLDAP_SESSION *session)
     errno = EINVAL;
     return;
   }
-  /* check if we should time out the connection */
-  if ((session->ld != NULL) && (nslcd_cfg->idle_timelimit > 0))
+  if (session->ld != NULL)
   {
-    /* if we have any running searches, don't time out */
-    for (i = 0; i < MAX_SEARCHES_IN_SESSION; i++)
-      if ((session->searches[i] != NULL) && (session->searches[i]->valid))
-        return;
-    /* consider timeout (there are no running searches) */
-    time(&current_time);
-    if ((session->lastactivity + nslcd_cfg->idle_timelimit) < current_time)
+    rc = ldap_get_option(session->ld, LDAP_OPT_DESC, &sd);
+    if (rc != LDAP_SUCCESS)
     {
-      log_log(LOG_DEBUG, "myldap_session_check(): idle_timelimit reached");
-      do_close(session);
+      myldap_err(LOG_WARNING, session->ld, rc,
+                 "ldap_get_option(LDAP_OPT_DESC) failed (ignored)");
+    }
+    else
+    {
+      /* check if the connection was closed by the peer */
+      if (getpeername(sd, &sa, &salen) == -1)
+      {
+        if (errno == ENOTCONN)
+        {
+          log_log(LOG_DEBUG, "myldap_session_check(): connection reset by peer");
+          do_close(session);
+          return;
+        }
+      }
+    }
+    /* check if we should time out the connection */
+    if (nslcd_cfg->idle_timelimit > 0)
+    {
+      /* if we have any running searches, don't time out */
+      for (i = 0; i < MAX_SEARCHES_IN_SESSION; i++)
+        if ((session->searches[i] != NULL) && (session->searches[i]->valid))
+          return;
+      /* consider timeout (there are no running searches) */
+      time(&current_time);
+      if ((session->lastactivity + nslcd_cfg->idle_timelimit) < current_time)
+      {
+        log_log(LOG_DEBUG, "myldap_session_check(): idle_timelimit reached");
+        do_close(session);
+      }
     }
   }
 }
@@ -1038,15 +1064,15 @@ int myldap_set_credentials(MYLDAP_SESSION *session, const char *dn,
   if (strlen(dn) >= sizeof(session->binddn))
   {
     log_log(LOG_ERR,
-            "myldap_set_credentials(): binddn buffer too small (%d required)",
-            strlen(dn));
+            "myldap_set_credentials(): binddn buffer too small (%lu required)",
+            (unsigned long) strlen(dn));
     return -1;
   }
   if (strlen(password) >= sizeof(session->bindpw))
   {
     log_log(LOG_ERR,
-            "myldap_set_credentials(): bindpw buffer too small (%d required)",
-            strlen(password));
+            "myldap_set_credentials(): bindpw buffer too small (%lu required)",
+            (unsigned long) strlen(password));
     return -1;
   }
   /* copy dn and password into session */
@@ -1365,7 +1391,7 @@ MYLDAP_SEARCH *myldap_search(MYLDAP_SESSION *session,
   /* allocate a new search entry */
   search = myldap_search_new(session, base, scope, filter, attrs);
   /* find a place in the session where we can register our search */
-  for (i = 0; (session->searches[i] != NULL) && (i < MAX_SEARCHES_IN_SESSION); i++)
+  for (i = 0; (i < MAX_SEARCHES_IN_SESSION) && (session->searches[i] != NULL); i++)
     /* nothing */ ;
   if (i >= MAX_SEARCHES_IN_SESSION)
   {
@@ -1376,7 +1402,7 @@ MYLDAP_SEARCH *myldap_search(MYLDAP_SESSION *session,
       *rcp = LDAP_OPERATIONS_ERROR;
     return NULL;
   }
-  /* regsiter search with the session so we can free it later on */
+  /* register search with the session so we can free it later on */
   session->searches[i] = search;
   /* do the search with retries to all configured servers */
   rc = do_retry_search(search);
@@ -1703,8 +1729,8 @@ static char **myldap_get_ranged_values(MYLDAP_ENTRY *entry, const char *attr)
   /* build the attribute name to find */
   if (mysnprintf(attbuf, sizeof(attbuf), "%s;range=0-*", attr))
   {
-    log_log(LOG_ERR, "myldap_get_ranged_values(): attbuf buffer too small (%d required)",
-            strlen(attr) + 10);
+    log_log(LOG_ERR, "myldap_get_ranged_values(): attbuf buffer too small (%lu required)",
+            (unsigned long) strlen(attr) + 10);
     return NULL;
   }
   /* keep doing lookups untul we can't get any more results */
