@@ -390,7 +390,9 @@ static void handleconnection(int sock, MYLDAP_SESSION *session)
     case NSLCD_ACTION_GROUP_BYNAME:     (void)nslcd_group_byname(fp, session); break;
     case NSLCD_ACTION_GROUP_BYGID:      (void)nslcd_group_bygid(fp, session); break;
     case NSLCD_ACTION_GROUP_BYMEMBER:   (void)nslcd_group_bymember(fp, session); break;
-    case NSLCD_ACTION_GROUP_ALL:        (void)nslcd_group_all(fp, session); break;
+    case NSLCD_ACTION_GROUP_ALL:
+      if (!nslcd_cfg->nss_disable_enumeration) (void)nslcd_group_all(fp, session);
+      break;
     case NSLCD_ACTION_HOST_BYNAME:      (void)nslcd_host_byname(fp, session); break;
     case NSLCD_ACTION_HOST_BYADDR:      (void)nslcd_host_byaddr(fp, session); break;
     case NSLCD_ACTION_HOST_ALL:         (void)nslcd_host_all(fp, session); break;
@@ -401,7 +403,9 @@ static void handleconnection(int sock, MYLDAP_SESSION *session)
     case NSLCD_ACTION_NETWORK_ALL:      (void)nslcd_network_all(fp, session); break;
     case NSLCD_ACTION_PASSWD_BYNAME:    (void)nslcd_passwd_byname(fp, session, uid); break;
     case NSLCD_ACTION_PASSWD_BYUID:     (void)nslcd_passwd_byuid(fp, session, uid); break;
-    case NSLCD_ACTION_PASSWD_ALL:       (void)nslcd_passwd_all(fp, session, uid); break;
+    case NSLCD_ACTION_PASSWD_ALL:
+      if (!nslcd_cfg->nss_disable_enumeration) (void)nslcd_passwd_all(fp, session, uid);
+      break;
     case NSLCD_ACTION_PROTOCOL_BYNAME:  (void)nslcd_protocol_byname(fp, session); break;
     case NSLCD_ACTION_PROTOCOL_BYNUMBER:(void)nslcd_protocol_bynumber(fp, session); break;
     case NSLCD_ACTION_PROTOCOL_ALL:     (void)nslcd_protocol_all(fp, session); break;
@@ -412,7 +416,9 @@ static void handleconnection(int sock, MYLDAP_SESSION *session)
     case NSLCD_ACTION_SERVICE_BYNUMBER: (void)nslcd_service_bynumber(fp, session); break;
     case NSLCD_ACTION_SERVICE_ALL:      (void)nslcd_service_all(fp, session); break;
     case NSLCD_ACTION_SHADOW_BYNAME:    (void)nslcd_shadow_byname(fp, session, uid); break;
-    case NSLCD_ACTION_SHADOW_ALL:       (void)nslcd_shadow_all(fp, session, uid); break;
+    case NSLCD_ACTION_SHADOW_ALL:
+      if (!nslcd_cfg->nss_disable_enumeration) (void)nslcd_shadow_all(fp, session, uid); break;
+      break;
     case NSLCD_ACTION_PAM_AUTHC:        (void)nslcd_pam_authc(fp, session, uid); break;
     case NSLCD_ACTION_PAM_AUTHZ:        (void)nslcd_pam_authz(fp, session); break;
     case NSLCD_ACTION_PAM_SESS_O:       (void)nslcd_pam_sess_o(fp, session); break;
@@ -838,8 +844,7 @@ int main(int argc, char *argv[])
       exit(EXIT_FAILURE);
     }
   }
-  pthread_sigmask(SIG_SETMASK, &oldmask, NULL);
-  /* install signalhandlers for some signals */
+  /* install signal handlers for some signals */
   install_sighandler(SIGHUP, sig_handler);
   install_sighandler(SIGINT, sig_handler);
   install_sighandler(SIGQUIT, sig_handler);
@@ -850,6 +855,8 @@ int main(int argc, char *argv[])
   install_sighandler(SIGUSR2, SIG_IGN);
   /* signal the starting process to exit because we can provide services now */
   daemonize_ready(EXIT_SUCCESS, NULL);
+  /* enable receiving of signals */
+  pthread_sigmask(SIG_SETMASK, &oldmask, NULL);
   /* wait until we received a signal */
   while ((nslcd_receivedsignal == 0) || (nslcd_receivedsignal == SIGUSR1))
   {
