@@ -126,6 +126,10 @@ class PasswdAllRequest(PasswdRequest):
 
     action = constants.NSLCD_ACTION_PASSWD_ALL
 
+    def handle_request(self, parameters):
+        if not cfg.nss_disable_enumeration:
+            return super(PasswdAllRequest, self).handle_request(parameters)
+
 
 def uid2entry(conn, uid):
     """Look up the user by uid and return the LDAP entry or None if the user
